==> kara-uc-1.1.66.tgz: package/src/kara-uc/components/UCFavorite/News/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import NewsComponent from '../All/newsComponent/index'
import tost from "kara-module-tost";
import Nothing from "../../nothing/nothing";
@inject('FavoriteStore','ConfigStore')

@observer
class KaraNews extends Component{
  constructor(props) {
    super(props)
    this.state = {
      iconList: [],
      showAll: false
    }
  }
  onBottom = ()=> {
    let pn = this.props.FavoriteStore.newsList.pageNo + 1
    if(pn <= this.props.FavoriteStore.newsList.pageCount){
      this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/cms',{keywords: this.props.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.newsList.pageSiz,
          pageNo: pn
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getNewsList(res, this.props.FavoriteStore.newsList.pageNo)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
    }
  }
  componentDidMount(){
    this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/cms',{keywords: this.props.keywords, 
      isShowRich: 'true', 
      pageInfo:{
        pageSize: this.props.FavoriteStore.newsList.pageSiz,
        pageNo: this.props.FavoriteStore.newsList.pageNo
      }
    }).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') { 
            this.props.FavoriteStore.getNewsList(res, this.props.FavoriteStore.newsList.pageNo)
        }
        else {
          tost({type:'error',msg:'列表信息加载失败',time:4}) 
        }
      }
    )
  }
  componentWillReceiveProps(nextProps) {
    if(this.props.keywords != nextProps.keywords) {
      this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/cms',{keywords: nextProps.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.newsList.pageSiz,
          pageNo: 1
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getNewsList(res, this.props.FavoriteStore.newsList.pageNo)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
    }
  }
  render(){
    const {ConfigStore, FavoriteStore, lang} = this.props
    const {karaui,httpAgent} = ConfigStore.config
    const {newsList} = FavoriteStore
    const { Scroll } = karaui
    return (
      <div className={css.KaraNews}>
      <Scroll onScrollBottom={this.onBottom}>
      {newsList.result.length>0 ? newsList.result.map((i,k)=> {
              return <NewsComponent
                key={k}
                fileAttr={i}
                fromPage='news'
                lang={lang}
                karaui={karaui}
                httpAgent={httpAgent}
                cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
                cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
            }) : <Nothing lang={lang}/>}
            </Scroll>
      </div>
    )
  }
}

export default KaraNews

==> kara-uc-1.1.93.tgz: package/src/kara-uc/components/UCFavorite/News/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import NewsComponent from '../All/newsComponent/index'
import {Tost} from "karaui";
import Nothing from "../../nothing/nothing";
@inject('FavoriteStore','ConfigStore')

@observer
class KaraNews extends Component{
  constructor(props) {
    super(props)
    this.state = {
      iconList: [],
      showAll: false
    }
  }
  onBottom = ()=> {
    let pn = this.props.FavoriteStore.newsList.pageNo + 1
    if(pn <= this.props.FavoriteStore.newsList.pageCount){
      this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/cms',{keywords: this.props.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.newsList.pageSiz,
          pageNo: pn
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getNewsList(res, this.props.FavoriteStore.newsList.pageNo)
          }
          else {
            Tost({type:'error',msg:'列表信息加载失败',time:4})
          }
        }
      )
    }
  }
  componentDidMount(){
    this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/cms',{keywords: this.props.keywords, 
      isShowRich: 'true', 
      pageInfo:{
        pageSize: this.props.FavoriteStore.newsList.pageSiz,
        pageNo: this.props.FavoriteStore.newsList.pageNo
      }
    }).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') { 
            this.props.FavoriteStore.getNewsList(res, this.props.FavoriteStore.newsList.pageNo)
        }
        else {
          Tost({type:'error',msg:'列表信息加载失败',time:4})
        }
      }
    )
  }
  componentWillReceiveProps(nextProps) {
    if(this.props.keywords != nextProps.keywords) {
      this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/cms',{keywords: nextProps.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.newsList.pageSiz,
          pageNo: 1
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getNewsList(res, this.props.FavoriteStore.newsList.pageNo)
          }
          else {
            Tost({type:'error',msg:'列表信息加载失败',time:4})
          }
        }
      )
    }
  }
  render(){
    const {ConfigStore, FavoriteStore, lang} = this.props
    const {karaui,httpAgent} = ConfigStore.config
    const {newsList} = FavoriteStore
    const { Scroll } = karaui
    return (
      <div className={css.KaraNews}>
      <Scroll onScrollBottom={this.onBottom}>
      {newsList.result.length>0 ? newsList.result.map((i,k)=> {
              return <NewsComponent
                key={k}
                fileAttr={i}
                fromPage='news'
                lang={lang}
                karaui={karaui}
                httpAgent={httpAgent}
                cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
                cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
            }) : <Nothing lang={lang}/>}
            </Scroll>
      </div>
    )
  }
}

export default KaraNews
